@@ -28,6 +28,12 @@ _METRIC_KIND_TO_PROTO = {
     MetricKind.FEATURE_LATENCY: pb.MetricKind.METRIC_KIND_FEATURE_LATENCY,
     MetricKind.FEATURE_STALENESS: pb.MetricKind.METRIC_KIND_FEATURE_STALENESS,
     MetricKind.FEATURE_VALUE: pb.MetricKind.METRIC_KIND_FEATURE_VALUE,
+    MetricKind.FEATURE_COMPUTED_COUNT: pb.MetricKind.METRIC_KIND_FEATURE_COMPUTED_COUNT,
+    MetricKind.FEATURE_LOOKED_UP_COUNT: pb.MetricKind.METRIC_KIND_FEATURE_LOOKED_UP_COUNT,
+    MetricKind.FEATURE_INTERMEDIATE_COUNT: pb.MetricKind.METRIC_KIND_FEATURE_INTERMEDIATE_COUNT,
+    MetricKind.FEATURE_COMPUTED_NULL_RATIO: pb.MetricKind.METRIC_KIND_FEATURE_COMPUTED_NULL_RATIO,
+    MetricKind.FEATURE_LOOKED_UP_NULL_RATIO: pb.MetricKind.METRIC_KIND_FEATURE_LOOKED_UP_NULL_RATIO,
+    MetricKind.FEATURE_INTERMEDIATE_NULL_RATIO: pb.MetricKind.METRIC_KIND_FEATURE_INTERMEDIATE_NULL_RATIO,
     MetricKind.FEATURE_WRITE: pb.MetricKind.METRIC_KIND_FEATURE_WRITE,
     MetricKind.FEATURE_NULL_RATIO: pb.MetricKind.METRIC_KIND_FEATURE_NULL_RATIO,
     MetricKind.RESOLVER_REQUEST_COUNT: pb.MetricKind.METRIC_KIND_RESOLVER_REQUEST_COUNT,
