@@ -108,6 +108,9 @@ from chalk.utils.grpc import AuthenticatedChalkClientInterceptor, TokenRefresher
 if TYPE_CHECKING:
     from pyarrow import RecordBatch, Table
 
+    from chalk._gen.chalk.server.v1.builder_pb2 import StartBranchResponse
+    from chalk._gen.chalk.server.v1.builder_pb2_grpc import BuilderServiceStub
+
 CHALK_GRPC_TRACE_ID_HEADER: str = "x-chalk-trace-id"
 
 
@@ -272,6 +275,14 @@ class StubProvider:
             raise RuntimeError("Unable to connect to API server.")
         return ModelRegistryServiceStub(self._server_channel)
 
+    @cached_property
+    def builder_stub(self) -> "BuilderServiceStub":
+        from chalk._gen.chalk.server.v1.builder_pb2_grpc import BuilderServiceStub
+
+        if self._server_channel is None:
+            raise RuntimeError("Unable to connect to API server.")
+        return BuilderServiceStub(self._server_channel)
+
     def __init__(
         self,
         token_config: TokenConfig,
@@ -466,6 +477,9 @@ class StubRefresher:
     def call_model_stub(self, fn: Callable[[ModelRegistryServiceStub], T]) -> T:
         return self._retry_callable(fn, lambda: self._stub.model_stub)
 
+    def call_builder_stub(self, fn: Callable[["BuilderServiceStub"], T]) -> T:
+        return self._retry_callable(fn, lambda: self._stub.builder_stub)
+
     @property
     def environment_id(self) -> str | None:
         return self._stub.environment_id
@@ -1403,6 +1417,7 @@ class ChalkGRPCClient:
         input_features: Optional[list[str]] = None,
         output_features: Optional[list[str]] = None,
         source_config: Optional[SourceConfig] = None,
+        dependencies: Optional[List[str]] = None,
     ) -> RegisterModelVersionResponse:
         """
         Register a model in the Chalk model registry.
@@ -1444,6 +1459,9 @@ class ChalkGRPCClient:
             e.g. `["user.is_spam"]`
         source_config : LocalSourceConfig, S3SourceConfig, HFSourceConfig, optional
             Config to pass credentials to access files from a remote source.
+        dependencies : List[str], optional
+            List of package dependencies needed to run this model.
+            e.g. ["torch==2.7.1", "numpy==1.26.4"]
         Returns
         -------
         ModelVersion
@@ -1455,7 +1473,7 @@ class ChalkGRPCClient:
 
         >>> client.register_model_version(
         ...     name="RiskModel",
-        ...     model=trained_sklearn_model,
+        ...     model=trained_pytorch_model,
         ...     model_type=ModelType.PYTORCH,
         ... )
 
@@ -1468,12 +1486,11 @@ class ChalkGRPCClient:
         ...     name="RiskModel",
         ...     model_paths=["./model.pth"],
         ...     model_type=ModelType.PYTORCH,
-        ...     input_schema=pa.large_string(),
-        ...     output_schema=pa.float32()
+        ...     input_schema={"content": pa.large_string()},
+        ...     output_schema={"prob": pa.float64()},
         ... )
 
         Register from s3 path:
-
         >>> client.register_model_version(
         ...     name="RiskModel",
         ...     model_paths=["s3://my-bucket/path/to/model.pth"],
@@ -1492,10 +1509,13 @@ class ChalkGRPCClient:
                 if output_schema is None and inferred_output_schema is not None:
                     output_schema = inferred_output_schema
 
+                if dependencies is None:
+                    dependencies = model_serializer.get_dependencies()
+
             if input_schema is None:
-                raise ValueError("You must specify at least one of input_schema to register a model version.")
-            if output_schema is None and output_features is None:
-                raise ValueError("You must specify at least one of output_schema to register a model version.")
+                raise ValueError("You must specify an input_schema to register a model version.")
+            if output_schema is None:
+                raise ValueError("You must specify an output_schema to register a model version.")
 
             try:
                 metadata_converted = model_serializer.convert_metadata_to_protobuf(metadata)
@@ -1555,6 +1575,7 @@ class ChalkGRPCClient:
                                     ),
                                     input_features=input_features,
                                     output_features=output_features,
+                                    python_dependencies=dependencies,
                                 ),
                                 aliases=aliases,
                                 metadata=metadata_converted,
@@ -1594,3 +1615,52 @@ class ChalkGRPCClient:
                 )
             )
         )
+
+    def await_branch_server_start(
+        self,
+        timeout_seconds: float = 300.0,
+        poll_interval_seconds: float = 2.0,
+    ) -> "StartBranchResponse":
+        """Start and wait for a branch server to be ready.
+
+        This method polls the branch server status until it is ready or a timeout is reached.
+        Both 'apply --branch' and 'query --branch' automatically start the branch server if
+        it isn't already running, so it isn't usually necessary to manually start it.
+
+        Parameters
+        ----------
+        timeout_seconds
+            Maximum time to wait for the branch server to start, in seconds. Defaults to 300 (5 minutes).
+        poll_interval_seconds
+            Time to wait between polling attempts, in seconds. Defaults to 2 seconds.
+
+        Returns
+        -------
+        StartBranchResponse
+            The response from the branch server indicating its state.
+
+        Raises
+        ------
+        TimeoutError
+            If the branch server doesn't start within the timeout period.
+
+        Examples
+        --------
+        >>> from chalk.client.client_grpc import ChalkGRPCClient
+        >>> client = ChalkGRPCClient()
+        >>> response = client.await_branch_server_start()
+        """
+        import time
+
+        from chalk._gen.chalk.server.v1.builder_pb2 import BranchScalingState, StartBranchRequest
+
+        start_time = time.time()
+        while True:
+            response = self._stub_refresher.call_builder_stub(lambda x: x.StartBranch(StartBranchRequest()))
+            if response.state == BranchScalingState.BRANCH_SCALING_STATE_SUCCESS:
+                return response
+            if (time.time() - start_time) >= timeout_seconds:
+                raise TimeoutError(
+                    f"Branch server did not start within {timeout_seconds} seconds. Last state: {BranchScalingState.Name(response.state)}"
+                )
+            time.sleep(poll_interval_seconds)
