@@ -7,6 +7,8 @@ from typing import TYPE_CHECKING, List, Literal, Optional, Union
 import pyarrow as pa
 from typing_extensions import Annotated
 
+from chalk.utils.json import is_pyarrow_json_type, pyarrow_json_type
+
 if TYPE_CHECKING:
     from pydantic import BaseModel, Field
 else:
@@ -18,7 +20,6 @@ else:
 __all__ = [
     "deserialize_dtype",
     "serialize_dtype",
-    "serialize_pyarrow_dtype",
 ]
 
 
@@ -66,6 +67,7 @@ class _DTypeCode(enum.IntEnum):
     LARGE_LIST = 26  # value type
     STRUCT = 27  # fields
     MAP = 28  # key field, item field
+    JSON = 29
 
 
 _TimeUnitCode = Literal["s", "ms", "us", "ns"]
@@ -97,6 +99,7 @@ class _SingletonDType(_BaseSerializedDType, frozen=True):
         _DTypeCode.STRING,
         _DTypeCode.LARGE_STRING,
         _DTypeCode.LARGE_BINARY,
+        _DTypeCode.JSON,
     ]
 
     def to_pyarrow_dtype(self) -> pa.DataType:
@@ -105,6 +108,8 @@ class _SingletonDType(_BaseSerializedDType, frozen=True):
         if self.type_code == _DTypeCode.STRING:
             # String is deprecated; automatically replacing with LargeString
             return pa.large_utf8()
+        if self.type_code == _DTypeCode.JSON:
+            return pyarrow_json_type()
         try:
             return getattr(pa, self.type_code.name.lower())()
         except AttributeError:
@@ -214,16 +219,13 @@ def deserialize_dtype(serialized_dtype: str) -> pa.DataType:
     return pa_dtype
 
 
-def serialize_pyarrow_dtype(pa_dtype: pa.DataType) -> _SerializedDType:
-    """Deprecated -- use `serialize_dtype` instead. For backwards compatibility with Engine"""
-    return _serialize_pyarrow_dtype(pa_dtype)
-
-
 def serialize_dtype(pa_dtype: pa.DataType) -> str:
     return _serialize_pyarrow_dtype(pa_dtype).json()
 
 
 def _serialize_pyarrow_dtype(pa_dtype: pa.DataType) -> _SerializedDType:
+    if is_pyarrow_json_type(pa_dtype):
+        return _SingletonDType(type_code=_DTypeCode.JSON)
     if pa.types.is_boolean(pa_dtype):
         return _SingletonDType(type_code=_DTypeCode.BOOL)
     if pa.types.is_uint8(pa_dtype):
@@ -268,9 +270,9 @@ def _serialize_pyarrow_dtype(pa_dtype: pa.DataType) -> _SerializedDType:
         return _SingletonDType(type_code=_DTypeCode.DATE32)
     if pa.types.is_date64(pa_dtype):
         return _SingletonDType(type_code=_DTypeCode.DATE64)
-    # if pa.types.is_duration(pa_dtype):
-    #     assert isinstance(pa_dtype, pa.DurationType)
-    #     return _TimeUnitDType(type_code=_DTypeCode.DURATION, time_unit=pa_dtype.unit)
+    if pa.types.is_duration(pa_dtype):
+        assert isinstance(pa_dtype, pa.DurationType)
+        return _TimeUnitDType(type_code=_DTypeCode.DURATION, time_unit=pa_dtype.unit)
 
     if pa.types.is_large_string(pa_dtype):
         return _SingletonDType(type_code=_DTypeCode.LARGE_STRING)
