@@ -175,7 +175,7 @@ class WindowConfigResolved:
     pick the primary key"""
 
     aggregation_kwargs: FrozenOrderedSet[Tuple[str, Any]]
-    """Only some aggregations allow kwargs, namely 'approx_top_k'."""
+    """Only some aggregations allow kwargs, namely 'approx_top_k', 'first_k', 'last_k'."""
 
     pyarrow_dtype: pa.DataType
 
