@@ -14,6 +14,7 @@ See https://docs.chalk.ai/docs/time for more details on feature time.
 Examples
 --------
 >>> from chalk.features import features
+>>> from chalk import FeatureTime
 >>> @features
 ... class User:
 ...     id: str
@@ -28,7 +29,7 @@ def feature_time() -> Any:
 
     Examples
     --------
-    >>> from chalk.features import features
+    >>> from chalk.features import features, feature_time
     >>> @features
     ... class User:
     ...     updated_at: datetime = feature_time()
@@ -48,15 +49,15 @@ def is_feature_time(f: Any) -> bool:
     Returns
     -------
     bool
-        `True` if the feature is a `FeatureTime` and `False` otherwise
+        `True` if the feature is a `FeatureTime` and `False` otherwise.
 
     Examples
     --------
-    >>> from chalk.features import features
+    >>> from chalk.features import features, FeatureTime
     >>> @features
     ... class User:
     ...     id: str
-    ...     updated_at: datetime = feature_time()
+    ...     updated_at: FeatureTime
     >>> assert is_feature_time(User.updated_at) is True
     >>> assert is_feature_time(User.id) is False
     """
