@@ -212,6 +212,9 @@ def _fnmatch_pathname_to_regex(pattern: str, directory_only: bool):
                 res.append("[{}]".format(stuff))
         else:
             res.append(re.escape(c))
-    if not directory_only:
-        res.append("$")
+    if directory_only:
+        res.append(r"/.*$")
+    else:
+        res.append("(/.*|[^/]*)$")
+
     return "".join(res)
