@@ -89,6 +89,8 @@ supported_aggs = (
     "approx_top_k",
     "array_agg",
     "count",
+    "min_by_n",
+    "max_by_n",
     "max",
     "mean",
     "min",
@@ -167,7 +169,7 @@ def _check_types(
         return
 
     joined_annotation = joined_feature.typ.parsed_annotation
-    if aggregation not in {"count", "approx_count_distinct", "approx_top_k", "array_agg"}:
+    if aggregation not in {"count", "approx_count_distinct", "approx_top_k", "min_by_n", "max_by_n", "array_agg"}:
         _validate_types(
             annotation=joined_annotation,
             permitted_types=(int, float),
@@ -279,8 +281,8 @@ def _parse_agg_function_call(expr: Underscore | None) -> Tuple[str, Underscore,
     if aggregation not in supported_aggs:
         raise ChalkParseError(f"aggregation should be one of {', '.join(supported_aggs)}")
 
-    if aggregation == "approx_top_k":
-        # Special arg validation for approx_top_k.
+    if aggregation in ("approx_top_k", "min_by_n", "max_by_n"):
+        # Special arg validation for approx_top_k, first_k, and last_k.
         if len(call_expr._chalk__args) > 0:
             raise ChalkParseError("should not have any positional arguments")
         elif {"k"} != call_expr._chalk__kwargs.keys():
