@@ -301,6 +301,13 @@ class UpsertNamedQueryGQL:
     validPlanNotRequired: Optional[bool] = True
 
 
+@dataclasses_json.dataclass_json
+@dataclass
+class ModelRelationGQL:
+    inputFeatures: List[str]
+    outputFeature: str
+
+
 @dataclasses_json.dataclass_json
 @dataclass
 class UpsertModelReferenceGQL:
@@ -309,6 +316,8 @@ class UpsertModelReferenceGQL:
     version: Optional[int] = None
     alias: Optional[str] = None
     asOf: Optional[datetime] = None
+    relations: Optional[List[ModelRelationGQL]] = None
+    resolvers: Optional[List[str]] = None
     code: Optional[str] = None
     sourceLineStart: Optional[int] = None
     sourceLineEnd: Optional[int] = None
