@@ -867,7 +867,9 @@ class ToProtoConverter:
                     if mat.backfill_start_time is not None
                     else None,
                     backfill_schedule=mat.backfill_schedule,
-                    approx_top_k_arg_k=aggregation_kwargs.get("k"),
+                    approx_top_k_arg_k=aggregation_kwargs.get("k")
+                    if mat.aggregation in ("approx_top_k", "min_by_n", "max_by_n")
+                    else None,
                 ),
                 tags=f.tags,
                 validations=ToProtoConverter.convert_validations(f.all_validations),
@@ -961,7 +963,9 @@ class ToProtoConverter:
                             if wmp.continuous_buffer_duration_seconds is not None
                             else None,
                             continuous_resolver=wmp.continuous_resolver,
-                            approx_top_k_arg_k=aggregation_kwargs.get("k"),
+                            approx_top_k_arg_k=aggregation_kwargs.get("k")
+                            if wmp.aggregation in ("approx_top_k", "min_by_n", "max_by_n")
+                            else None,
                         )
                         if wmp is not None
                         else None,
@@ -1287,17 +1291,18 @@ class ToProtoConverter:
         for feat, expr in (r.feature_expressions or {}).items():
             expr_proto = cls.convert_underscore(expr)
             feature_expressions[str(feat)] = graph_pb2.FeatureExpression(underscore_expr=expr_proto)
-        message_producer: pb.StreamResolverMessageProducer | None = None
+        message_producer: pb.StreamResolverMessageProducerParsed | None = None
         if r.message_producer_parsed is not None:
-            message_producer = pb.StreamResolverMessageProducer(
+            message_producer = pb.StreamResolverMessageProducerParsed(
                 send_to=ToProtoConverter.create_stream_source_reference(r.message_producer_parsed.send_to),
                 output_features=r.message_producer_parsed.output_features,
-                feature_expressions={
+                transformations={
                     str(k): graph_pb2.FeatureExpression(underscore_expr=cls.convert_underscore(v))
                     for k, v in r.message_producer_parsed.feature_expressions.items()
                 }
                 if r.message_producer_parsed.feature_expressions is not None
                 else None,
+                format=r.message_producer_parsed.format,
             )
 
         # convert_proto_message_type_to_pyarrow_type(global_value.DESCRIPTOR)
