@@ -1403,7 +1403,7 @@ def _get_stream_resolver(
             updates_materialized_aggregations=True,
             sql_settings=None,
             feature_expressions=None,
-            message_producer=None,
+            message_producer_parsed=None,
         )
     except Exception as e:
         message = f"Streaming SQL file resolver could not be instantiated, {e}"
