@@ -73,7 +73,7 @@ class ResolverAnnotationParser:
             # All fancy ast parsing would appear within the subscript of a df __getitem__
             annotation = ast.Subscript(
                 value=annotation.value,
-                slice=convert_slice(annotation.slice),
+                slice=convert_slice(annotation.slice),  # pyright: ignore[reportArgumentType]
                 ctx=annotation.ctx,
             )
         return eval_converted_expr(annotation, self.glbs, self.lcls)
